@@ -12,7 +12,7 @@ type Generator interface {
 	// GenerateParams interprets the ApplicationSet and generates all relevant parameters for the application template.
 	// The expected / desired list of parameters is returned, it then will be render and reconciled
 	// against the current state of the Applications in the cluster.
-	GenerateParams(appSetGenerator *argoprojiov1alpha1.ApplicationSetGenerator) ([]map[string]string, error)
+	GenerateParams(appSetGenerator *argoprojiov1alpha1.ApplicationSetGenerator, applicationSetInfo *argoprojiov1alpha1.ApplicationSet) ([]map[string]string, error)
 
 	// GetRequeueAfter is the the generator can controller the next reconciled loop
 	// In case there is more then one generator the time will be the minimum of the times.
@@ -25,3 +25,8 @@ type Generator interface {
 
 var EmptyAppSetGeneratorError = errors.New("ApplicationSet is empty")
 var NoRequeueAfter time.Duration
+
+// DefaultRequeueAfterSeconds is used when GetRequeueAfter is not specified, it is the default time to wait before the next reconcile loop
+const (
+	DefaultRequeueAfterSeconds = 3 * time.Minute
+)
